@@ -17,11 +17,11 @@ URI::NamespaceMap - Class holding a collection of namespaces
 
 =head1 VERSION
 
-Version 1.05_01
+Version 1.05_02
 
 =cut
 
-our $VERSION = '1.05_01';
+our $VERSION = '1.05_02';
 
 
 =head1 SYNOPSIS
@@ -194,6 +194,9 @@ sub _scrub_uri {
 			if ($uri->isa('URI::Namespace')) {
 				$uri = $uri->as_string;
 			}
+			elsif ($uri->isa('IRI')) {
+				$uri = $uri->as_string;
+			}
 			elsif ($uri->isa('URI')) {
 				# it's probably not necessary to do this, but whatever
 				$uri = $uri->as_string;
@@ -267,7 +270,6 @@ sub abbreviate {
 
 	my $prefix = $self->prefix_for($uri);
 
-	# XXX is this actually the most desirable behaviour?
 	return unless defined $prefix;
 
 	my $nsuri = _scrub_uri($self->namespace_uri($prefix));
